=====
Pureftpd admin
=====

Pureftpd admin is a Django project to manage accounts in pureftpd server based on mysql auth backend.

Quick start
-----------

=====
Pureftpd admin
=====

Pureftpd admin is a Django project to manage accounts in pureftpd server based on mysql auth backend.

Quick start
-----------
1. Add "pureftpd_admin" to your INSTALLED_APPS setting like this::

      INSTALLED_APPS = (
          ...
          'django.contrib.staticfiles', #!!!
          'pureftpd_admin',
      )

2. Include the polls URLconf in your project urls.py like this::

      url(r'^', include('pureftpd_admin.urls')),

3. Write you own settings with default django options and this::

    FTPUSERS_DEFAULT_UID
    FTPUSERS_DEFAULT_GID
    FTPUSERS_DEFAULT_UPLOAD_BANDWIDTH
    FTPUSERS_DEFAULT_DOWNLOAD_BANDWIDTH
    FTPUSERS_DEFAULT_UPLOAD_RATIO
    FTPUSERS_DEFAULT_DOWNLOAD_RATIO
    FTPUSERS_DEFAULT_QUOTA_SIZE
    FTPUSERS_DEFAULT_QUOTA_FILES
    FTPUSERS_DEFAULT_IPACCESS
    FTPUSERS_DEFAULT_HOSTNAME # if not defined used platform.node()

4. Create database in Mysql for storage user::

    ./manage.py syncdb
    # or if you use South
    ./manage.py syncdb --all or ./manage.py migrate

5. Start the development or production server and visit http://127.0.0.1:8000/admin/ftpusers/
   to create a new ftp user (default Admin interface should be enabled).

6. Create config pureftpd for authenticate through sql backend - mysql::

    ./manage.py generate_conf --help

.